/**
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 * 
 * Contact Information:
 * beck et al. projects GmbH
 * Theresienhoehe 13
 * 80336 Munich
 * Phone: +49-89-5442530
 * mailto: info@bea.de
 */
package de.bsvrz.ars.export.interfaces;

import de.bsvrz.ars.export.prot.ProtocollerAdapter;

/**
 * Alle Klassen die über den Fortschritt des Exportvorgangs berichten sollen, müssen dieses
 * Interface implementieren
 * 
 * @author beck et al. projects GmbH
 * @author Phil Schrettenbrunner
 * @version $Revision: 1.1 $ / $Date: 2008/01/22 16:39:42 $ / ($Author: yvonnes $)
 */
public interface ProgressListener {
    /**
     * Führt Initialisierungsschritte durch, die eventuell noch nach dem Erzeugen der Intanz gemacht
     * werden müssen
     * 
     * @param pa Threadobjekt
     */
    public void init(ProtocollerAdapter pa);


    /**
     * Der String s wird im Progressfenster neben dem Label "Format" angezeigt.
     * 
     * @param s der anzuzeigende String
     */
    public void setFormat(String s);


    /**
     * Jedes mal, wenn ein Datensatz empfangen wurde, sollte diese Methode aufgerufen werden, damit
     * der counter eins höher gezählt werden kann
     */
    public void recordReceived();


    /**
     * Signalisiert, dass eine neue Datenspezifikation begonnen wird
     * 
     * @param current TODO
     * @param max TODO
     * @param resetCounter TODO
     */
    public void nextDataSpecification(int current, int max, boolean resetCounter);


    /**
     * signalisiert, dass der Progress fertig ist
     */
    public void done();
}
